@@ -15,14 +15,12 @@ Table formatting can be defined as a ``gptable.Theme``, which is passed to the A
 import gptables as gpt
 import pandas as pd
 import numpy as np
-import os
-
+from pathlib import Path
 
 ## Read data and arrange
-funcs = [np.mean, np.median]
-parent_dir = os.path.dirname(os.path.realpath(__file__))
+parent_dir = Path(__file__).parent
 
-iris_data = pd.read_csv(parent_dir + "/iris.csv")
+iris_data = pd.read_csv(parent_dir / "iris.csv")
 iris_data = iris_data.loc[:, ["class", "sepal_length", "sepal_width"]]
 
 iris_summary = iris_data.groupby("class").agg(np.mean)
@@ -75,12 +73,13 @@ kwargs = {"title": title,
 iris_table = gpt.GPTable(
         table = iris_summary,
         **kwargs
-        )        
+        )
 
 ## Use write_workbook to win!
-output_path = parent_dir + "/python_iris_gptable.xlsx"
-gpt.write_workbook(
-        filename = output_path,
-        sheets = {"iris flower dimensions": iris_table}
-        )
-print("Output written at: ", output_path)
+if __name__ is "__main__":
+        output_path = parent_dir / "python_iris_gptable.xlsx"
+        gpt.write_workbook(
+                filename = output_path,
+                sheets = {"Iris Flower Dimensions": iris_table}
+                )
+        print("Output written at: ", output_path)
